summaryrefslogtreecommitdiff
path: root/userdiff.c
diff options
context:
space:
mode:
authorJunio C Hamano <gitster@pobox.com>2023-02-15 17:11:52 -0800
committerJunio C Hamano <gitster@pobox.com>2023-02-15 17:11:52 -0800
commit4a6e6b0d5b91b0db45c6fefc8a0f17af2c4b3b83 (patch)
tree0b421dcb8357ffdf56973a05c0af92e6eeaae52e /userdiff.c
parentf7c208cdf5b10df89a28320628e19e4c4a121629 (diff)
parent93d52ed050f5613897b73e75961df5c589d63a4b (diff)
downloadgit-4a6e6b0d5b91b0db45c6fefc8a0f17af2c4b3b83.tar.xz
Merge branch 'ar/userdiff-java-update'
Userdiff regexp update for Java language. * ar/userdiff-java-update: userdiff: support Java sealed classes userdiff: support Java record types userdiff: support Java type parameters
Diffstat (limited to 'userdiff.c')
-rw-r--r--userdiff.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/userdiff.c b/userdiff.c
index d71b82feb7..94cca1a2a8 100644
--- a/userdiff.c
+++ b/userdiff.c
@@ -170,8 +170,8 @@ PATTERNS("html",
"[^<>= \t]+"),
PATTERNS("java",
"!^[ \t]*(catch|do|for|if|instanceof|new|return|switch|throw|while)\n"
- /* Class, enum, and interface declarations */
- "^[ \t]*(([a-z]+[ \t]+)*(class|enum|interface)[ \t]+[A-Za-z][A-Za-z0-9_$]*[ \t]+.*)$\n"
+ /* Class, enum, interface, and record declarations */
+ "^[ \t]*(([a-z-]+[ \t]+)*(class|enum|interface|record)[ \t]+.*)$\n"
/* Method definitions; note that constructor signatures are not */
/* matched because they are indistinguishable from method calls. */
"^[ \t]*(([A-Za-z_<>&][][?&<>.,A-Za-z_0-9]*[ \t]+)+[A-Za-z_][A-Za-z_0-9]*[ \t]*\\([^;]*)$",